@@ -8,10 +8,12 @@
 Plugin.define do
 	name "Charset"
 	authors [
-		"Andrew Horton"
+		"Andrew Horton",
+		"Lars Kulseng"
 		# v0.2 # added example sites
+		# v0.3 # fixed reference bugs
 	]
-	version "0.2"
+	version "0.3"
 	description "Detects the character set of a page, this is required for MongoDB output. Only checks the meta content tag, not the HTTP header. It tries the specified charset, then ascii, then utf-8 then uses CharDet from the rchardet gem which is CPU intensive / slow. Tests conversion to UTF-8 using Iconv. Returns Failed if unsuccessful."
 
 	# requires rchardet
@@ -25,18 +27,9 @@ Plugin.define do
 	end
 
 passive do
-	def get_charset(body)
-    charset = nil
-    meta_content_tag = body.scan(/<meta[^>]+Content-Type[^>]+>/i)[0]
-    # puts meta_content_tag
-    unless meta_content_tag.nil? or not meta_content_tag =~ /charset=['"]?([a-zA-Z0-9_-]+)/i
-      charset = meta_content_tag.scan(/charset=['"]?([a-zA-Z0-9_-]+)/i)[0][0]
-      charset.upcase!
-    end
-    charset
-  end
-  
+
   m = []
+  body=@body
 
 =begin
 			Arabic (Windows)	Windows-1256
@@ -76,10 +69,15 @@ passive do
 
 		trythese = %w| UTF_8 ASCII | # it's stack backwards
 
-		charset = get_charset(body)
+		charset = nil
+		meta_content_tag = body.scan(/<meta[^>]+Content-Type[^>]+>/i)[0]
+		# puts meta_content_tag
+		unless meta_content_tag.nil? or not meta_content_tag =~ /charset=['"]?([a-zA-Z0-9_-]+)/i
+			charset = meta_content_tag.scan(/charset=['"]?([a-zA-Z0-9_-]+)/i)[0][0]
+			charset.upcase!
+		end
 		trythese.push(charset) unless charset.nil?
 
-
 		found=false
 		while trythis = trythese.pop
 		begin
@@ -87,7 +85,7 @@ passive do
 			found = true
 			m << {:string=> trythis}
 			break
-		rescue		
+		rescue
 			#
 		end
 
