@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "ASProxy" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-25
+Plugin.define do
+name "ASProxy"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-25
+]
 version "0.1"
 description "ASProxy is a free and open-source web proxy which allows the user to surf the net anonymously."
 website "http://asproxy.sourceforge.net/"
