@@ -2,14 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2012-01-08 #
-# Added logo image matches
-# Added www-authenticate header match
-##
-Plugin.define "Billion-Router" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-05
+Plugin.define do
+name "Billion-Router"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-05
+  # v0.2 # 2012-01-08 # Added logo image matches. Added www-authenticate header match. 
+]
 version "0.2"
 description "Billion router"
 website "http://www.billion.com/product/product.html"
@@ -30,7 +30,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# WWW-Authenticate: Basic realm="Billion Sky" 
