@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Cyn_in" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-06-04
+Plugin.define do
+name "Cyn_in"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-06-04
+]
 version "0.1"
 description "Cyn.in is a collaboration software that inter-connects your people with each other and their collective knowledge, seamlessly."
 website "http://www.cynapse.com/cynin"
