@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "DynamicWeb" do
-author "Guillaume Delacour <gui@iroqwa.org>" # 2017-04-15
+Plugin.define do
+name "DynamicWeb"
+authors [
+  "Guillaume Delacour <gui@iroqwa.org>", # 2017-04-15
+]
 version "0.1"
 description "Dynamicweb is the All-In-One Platform for Content Management, Ecommerce, Digital Marketing and Integration."
 website "https://dynamicweb.com/"
