@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "E-Manage-MySchool" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-25
+Plugin.define do
+name "E-Manage-MySchool"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-25
+]
 version "0.1"
 description "My School is an essential web-based school management system with an influential impact on schools' performance. It is a deliberate and comprehensive user-friendly system that offers numerous features to students, parents, teachers, and school management. It presents a well organized and effective collaboration tool between all parties."
 website "http://em.com.eg/"
