@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "FreePBX" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-06-12
+Plugin.define do
+name "FreePBX"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-06-12
+]
 version "0.1"
 description "FreePBX is an easy to use web based GUI (graphical user interface) that controls and manages Asterisk"
 website "http://www.freepbx.org/"
@@ -16,7 +19,7 @@ website "http://www.freepbx.org/"
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# WWW-Authenticate realm
