@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "HP-StorageWorks-Library" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-02-16
+Plugin.define do
+name "HP-StorageWorks-Library"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-02-16
+]
 version "0.1"
 description "HP StorageWorks Library and Tape Tools (L&TT) is a diagnostic tool for all of HP's tape storage and magneto-optical storage products."
 website "http://h18006.www1.hp.com/products/storageworks/ltt/index.html"
