@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Isolsoft-Support-Center" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-06-25
+Plugin.define do
+name "Isolsoft-Support-Center"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-06-25
+]
 version "0.1"
 description "Support Center is a fully automated Help Desk solution."
 website "http://www.isolsoft.com/"
