@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 #
-# Fixed regex
-##
-Plugin.define "Linksys-NAS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-07-15
+Plugin.define do
+name "Linksys-NAS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-07-15
+  # v0.2 # Fixed regex. 
+]
 version "0.2"
 description "Linksys NAS web frontend"
 website "http://www.linksys.com/"
@@ -24,7 +25,7 @@ matches [
 
 ]
 
-def passive
+passive do
         m=[]
 
         if @body =~ /	 <td nowrap class="hst">&nbsp; &nbsp;Version:<\/td>/
