@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "MGB-OpenSource-Guestbook" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-07-22
+Plugin.define do
+name "MGB-OpenSource-Guestbook"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-07-22
+]
 version "0.1"
 description "MGB OpenSource Guestbook"
 website "http://www.m-gb.org/"
