@@ -2,14 +2,16 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2016-04-21 # Andrew Horton
-# Moved patterns from passive function to matches[]
-##
-Plugin.define "Microsoft-WinCE" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-03-13
-version "0.2"
+Plugin.define do
+name "Microsoft-WinCE"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-03-13
+  "Andrew Horton", # v0.2 # 2016-04-21 # Moved patterns from passive function to matches[]. 
+  "Andrew Horton", # v0.3 # 2019-07-10 # Fix warning: character class has duplicated range
+]
+version "0.3"
 description "Microsoft Windows CE HTTP Server"
 website "http://msdn.microsoft.com/en-us/library/ms834461.aspx"
 
@@ -20,7 +22,7 @@ matches [
 	# HTTP Server Header
 	{ :regexp=>/^Microsoft-WinCE/, :search=>"headers[server]" },
 	# Version Detection # HTTP Server Header
-	{ :version=>/^Microsoft-WinCE\/([^\s^\r^\n]+)$/, :search=>"headers[server]" },
+	{ :version=>/^Microsoft-WinCE\/([\S]+)/, :search=>"headers[server]" },
 
 ]
 
