@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Open-Freeway" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-06-05 
+Plugin.define do
+name "Open-Freeway"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-06-05 
+]
 version "0.1"
 description "Freeway is by far the largest and most fully featured Open Source eCommerce platform. It doesn't just sell products but extends to sell in some very fancy new ways and is very configurable."
 website "http://www.openfreeway.org/"
@@ -30,7 +33,7 @@ matches [
 
 ]
 
-def passive
+passive do
         m=[]
 	m << {:name=>"fEcom Cookie", :certainty=>75 } if @headers["set-cookie"] =~ /fEcom=/
         m
