@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 #
-# Updated version detection and ghdb match
-##
-Plugin.define "PhilBoard" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-06-27
+Plugin.define do
+name "PhilBoard"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-06-27
+  # v0.2 # Updated version detection and ghdb match. 
+]
 version "0.2"
 description "PhilBoard - ASP powered forum"
 website "http://www.philboards.com/"
