@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "PHP-Mall" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-06-20
+Plugin.define do
+name "PHP-Mall"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-06-20
+]
 version "0.1"
 description "PHP Mall (formerly iBoutique.MALL) is a powerful and flexible multi vendors mall solution."
 website "http://www.netartmedia.net/mall"
