@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "PortalApp" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-07-10
+Plugin.define do
+name "PortalApp"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-07-10
+]
 version "0.1"
 description "PortalApp is a fast, flexible, configurable CMS and portal system that can be used to create everything from Blogs to Web sites."
 website "http://www.portalapp.com/"
