@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "SQL-Buddy" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-09-28
+Plugin.define do
+name "SQL-Buddy"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-09-28
+]
 version "0.1"
 description "SQL Buddy - Web based MySQL administration"
 website "http://www.sqlbuddy.com/"
@@ -24,7 +27,7 @@ dorks [
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# Help link
