@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-02-19 #
-# Updated version detection
-##
-Plugin.define "XchangeBoard" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-21
+Plugin.define do
+name "XchangeBoard"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-21
+  # v0.2 # 2011-02-19 # Updated version detection. 
+]
 version "0.2"
 description "Old forum"
 website "http://www.xchangeboard.de"
